aboutsummaryrefslogtreecommitdiff
path: root/core/testdata/format/javaCodeInParam.java
diff options
context:
space:
mode:
Diffstat (limited to 'core/testdata/format/javaCodeInParam.java')
-rw-r--r--core/testdata/format/javaCodeInParam.java10
1 files changed, 6 insertions, 4 deletions
diff --git a/core/testdata/format/javaCodeInParam.java b/core/testdata/format/javaCodeInParam.java
index 73025fcc..0d1607ba 100644
--- a/core/testdata/format/javaCodeInParam.java
+++ b/core/testdata/format/javaCodeInParam.java
@@ -1,5 +1,7 @@
-/**
- * @param T this is {@code some code} and other text
- */
-class C<T> {
+class C {
+
+ /**
+ * @param par this is {@code some code} and other text
+ */
+ public void withParam(String par) {}
}